#
# spec file for package modello-maven-plugin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global parent modello
%global subname maven-plugin
Name:           %{parent}-%{subname}
Version:        2.4.0
Release:        150200.3.10.1
Summary:        Modello Maven Plugin
License:        Apache-2.0 AND MIT
Group:          Development/Libraries/Java
URL:            https://codehaus-plexus.github.io/modello/modello-maven-plugin
Source0:        https://repo1.maven.org/maven2/org/codehaus/%{parent}/%{parent}/%{version}/%{parent}-%{version}-source-release.zip
Source1:        https://www.apache.org/licenses/LICENSE-2.0.txt
Patch0:         0001-Fix-ModelloCli-after-moving-from-Plexus-to-JSR330.patch
Patch1:         0002-Add-support-for-domAsXpp3-and-fail-if-the-old-Java5-.patch
Patch2:         0003-Fix-Snakeyaml.patch
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  unzip
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.codehaus.modello:modello-core) = %{version}
BuildRequires:  mvn(org.codehaus.modello:modello-plugin-converters) = %{version}
BuildRequires:  mvn(org.codehaus.modello:modello-plugin-dom4j) = %{version}
BuildRequires:  mvn(org.codehaus.modello:modello-plugin-jackson) = %{version}
BuildRequires:  mvn(org.codehaus.modello:modello-plugin-java) = %{version}
BuildRequires:  mvn(org.codehaus.modello:modello-plugin-jdom) = %{version}
BuildRequires:  mvn(org.codehaus.modello:modello-plugin-jsonschema) = %{version}
BuildRequires:  mvn(org.codehaus.modello:modello-plugin-sax) = %{version}
BuildRequires:  mvn(org.codehaus.modello:modello-plugin-snakeyaml) = %{version}
BuildRequires:  mvn(org.codehaus.modello:modello-plugin-stax) = %{version}
BuildRequires:  mvn(org.codehaus.modello:modello-plugin-velocity) = %{version}
BuildRequires:  mvn(org.codehaus.modello:modello-plugin-xdoc) = %{version}
BuildRequires:  mvn(org.codehaus.modello:modello-plugin-xpp3) = %{version}
BuildRequires:  mvn(org.codehaus.modello:modello-plugin-xsd) = %{version}
BuildRequires:  mvn(org.codehaus.plexus:plexus-build-api)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.codehaus.plexus:plexus:pom:)
#!BuildRequires: maven-compiler-plugin-bootstrap
#!BuildRequires: maven-jar-plugin-bootstrap
#!BuildRequires: maven-javadoc-plugin-bootstrap
#!BuildRequires: maven-plugin-plugin-bootstrap
#!BuildRequires: maven-resources-plugin-bootstrap
#!BuildRequires: maven-surefire-plugin-bootstrap
BuildArch:      noarch

%description
Modello is a Data Model toolkit in use by the Apache Maven Project.

Modello is a framework for code generation from a simple model.
Modello generates code from a simple model format based on a plugin
architecture, various types of code and descriptors can be generated
from the single model, including Java POJOs, XML
marshallers/unmarshallers, XSD and documentation.

Modello Maven Plugin enables the use of Modello in Maven builds.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.

%prep
%setup -q -n %{parent}-%{version}
%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p1
cp -p %{SOURCE1} LICENSE

%pom_remove_plugin :maven-site-plugin
%pom_remove_plugin :maven-enforcer-plugin
%pom_remove_plugin :sisu-maven-plugin

%pom_remove_dep :sisu-guice modello-core
%pom_add_dep com.google.inject:guice modello-core

%pom_change_dep -r :velocity-engine-core :velocity

%pom_remove_dep :jackson-bom

%build
pushd %{name}
%{mvn_file} :{*} %{parent}/@1
%{mvn_build} -f -- -Dsource=8
popd

%install
pushd %{name}

%mvn_install

popd
%fdupes -s %{buildroot}%{_javadocdir}

%files -f %{name}/.mfiles
%license LICENSE

%files javadoc -f %{name}/.mfiles-javadoc
%license LICENSE

%changelog
* Sat May  4 2024 fstrba@suse.com
- Upgrade to upstream version 2.4.0
  * New features and improvements
    + Keep license structure
    + Support addition of license header to generated files
    + Make generated code - Java 8 based by default
    + threadsafety
  * Bug Fixes
    + Revert snakeyaml to 1.33 (as 2.x is not fully compatible with
    1.x). This change is reverted and SnakeYaml fixed by the
    0003-Fix-Snakeyaml.patch
- Modified patches:
  * 0001-Fix-ModelloCli-after-moving-from-Plexus-to-JSR330.patch
  * 0002-Add-support-for-domAsXpp3-and-fail-if-the-old-Java5-.patch
  * 0003-Fix-Snakeyaml.patch
    + rediff to changed context
* Fri May  3 2024 fstrba@suse.com
- Added patch:
  * 0003-Fix-Snakeyaml.patch
    + patch to fix the modello-plugin-snakeyaml with SnakeYaml 2.2
    + https://github.com/codehaus-plexus/modello/pull/439
* Wed May  1 2024 fstrba@suse.com
- Build against the new codehaus plexus build api 1.2.0
- Removed patch:
  * 0003-Revert-Switch-to-codehaus-plexus-build-api-1.2.0-345.patch
    + not needed any more
* Tue Apr 16 2024 fstrba@suse.com
- Build all modello plugins
* Sun Apr 14 2024 fstrba@suse.com
- Upgrade to upstrem version 2.3.0
  * Changes of version 2.3.0
    + Kill off dead Plexus
    + Fix for #366
  * Changes of version 2.2.0
    + Parse javadoc tags in xdoc generator (only @since is supported
    atm)
    + Use generic in Xpp3Reader for JDK 5+
    + Get rid of usage deprecated Reader/WriterFactory
    + Make spotless plugin work with Java 21
    + Support java source property being discovered as 1.x
    + Fix thread safety issues by not using singletons for
    generators
    + Improve discovering javaSource based on maven.compiler
    properties, default as 8
    + Switch Plexus Annotation to JSR-330
    + Make spotless plugin work with Java 21
- Modified patches:
  * 0001-Revert-Switch-to-codehaus-plexus-build-api-1.2.0-345.patch
  - > 0003-Revert-Switch-to-codehaus-plexus-build-api-1.2.0-345.patch
  * modello-cli-domasxpp3.patch ->
    0002-Add-support-for-domAsXpp3-and-fail-if-the-old-Java5-.patch
    + rediff to changed context
- Added patch:
  * 0001-Fix-ModelloCli-after-moving-from-Plexus-to-JSR330.patch
    + Fix for https://github.com/codehaus-plexus/modello/issues/434
    submitted upstream
* Tue Apr  2 2024 fstrba@suse.com
- Add dependency on plexus-xml where relevant
  * this will be needed for smooth upgrade to plexus-utils 4.0.0
* Wed Feb 21 2024 fstrba@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Sep  6 2023 fstrba@suse.com
- Upgrade to upstream version 2.1.2
  * Changes of version 2.1.2
    + Switch to codehaus plexus-build-api 1.2.0 (reverted by a
    patch in this package)
    + Add plexus 13 parent and reformat
    + Remove readonly flag from basedir: support .mdo from any
    location
    + Require Maven 3.5.4+
    + Prepare to run with Java 19+
  * Changes of version 2.1.1
    + replace generatedBy context value by template
    + add velocityBasedir to select where to load (shared) .vm from
  * Changes of version 2.1.0
    + Make the Xpp3Reader#read(XmlPullParser, boolean strict) public
    + Fix json encoding
    + Support arbitrary element names via 'xs:any'
    + Call setter only after object has been populated
    + replace handwritten components.xml with annotations
    + Optionally enforce required elements in XSDs
    + Add a velocity template based generator
    + Use optimised plexus-utils CachingWriter
- Added patch:
  * 0001-Revert-Switch-to-codehaus-plexus-build-api-1.2.0-345.patch
    + use the version of plexus-build-api that we have packaged
- Modified patch:
  * modello-cli-domasxpp3.patch
    + rediff to changed context
* Fri May 13 2022 fstrba@suse.com
- Upgrade to upstream version 2.0.0
  * New features and improvements
    + Add Modello 2.0.0 model XSD
    + Manage xdoc anchor name conflicts (2 classes with same anchor)
    + Drop unnecessary check for identical branches
    + Require Maven 3.1.1
    + Use a caching writer to avoid overwriting identical files
    + Migrate from codehaus:wstx to
    com.fasterxml.woodstox:woodstox-core 6.2.4
    + Make location handling more memory efficient
    + Xpp3 extended writer
    + Refactor some old java APIs usage
    + Add a new field fileComment
  * Bug Fixes
    + Fix javaSource default value
    + Fix modello-plugin-snakeyaml
  * Dependency updates
    + Bump maven-javadoc-plugin from 3.3.1 to 3.3.2
    + Bump release-drafter/release-drafter from 5.17.6 to 5.18.0
    + Bump taglist-maven-plugin from 2.4 to 3.0.0
    + Bump checkstyle from 9.2.1 to 9.3
    + Bump xmlunit-core from 2.8.4 to 2.9.0
    + Bump junit from 4.12 to 4.13.1 in
    /modello-maven-plugin/src/it/maven-model
    + Bump xercesImpl from 2.12.1 to 2.12.2 in
    /modello-plugins/modello-plugin-xsd
    + Bump xercesImpl from 2.12.1 to 2.12.2 in
    /modello-plugins/modello-plugin-jsonschema
    + Bump mavenPluginTools from 3.6.2 to 3.6.4
    + Bump maven-compiler-plugin from 3.8.1 to 3.9.0
    + Bump maven-jar-plugin from 3.2.0 to 3.2.2
    + Bump release-drafter/release-drafter from 5.15.0 to 5.17.6
    + Bump woodstox-core from 6.2.7 to 6.2.8
    + Bump maven-release-plugin from 3.0.0-M4 to 3.0.0-M5
    + Bump checkstyle from 9.2 to 9.2.1
    + Bump maven-site-plugin from 3.9.1 to 3.10.0
    + Bump snakeyaml from 1.29 to 1.30
    + Bump jackson-bom from 2.13.0 to 2.13.1
    + Bump xmlunit-core from 2.8.3 to 2.8.4
    + Bump plexus-compiler-javac from 2.8.8 to 2.9.0
    + Bump woodstox-core from 6.2.6 to 6.2.7
    + Bump maven-shared-resources from 3 to 4
    + Bump plexus-compiler-api from 2.8.8 to 2.9.0
    + Bump mavenPluginTools from 3.6.1 to 3.6.2
    + Bump checkstyle from 9.0.1 to 9.2
    + Bump xmlunit-core from 2.8.2 to 2.8.3
    + Bump checkstyle from 9.0 to 9.0.1
    + Bump checkstyle from 8.45.1 to 9.0
    + Bump jackson-bom from 2.12.5 to 2.13.0
    + Bump org.eclipse.sisu.plexus from 0.3.4 to 0.3.5
    + Bump jsoup from 1.14.2 to 1.14.3
    + Bump actions/setup-java from 2.3.0 to 2.3.1
    + Bump maven-pmd-plugin from 3.14.0 to 3.15.0
    + Bump maven-javadoc-plugin from 3.3.0 to 3.3.1
    + Bump plexus-utils from 3.2.0 to 3.4.1
    + Bump jackson-bom from 2.12.4 to 2.12.5
    + Bump actions/setup-java from 2.2.0 to 2.3.0
    + Bump checkstyle from 8.42 to 8.45.1
    + Bump plexus-velocity from 1.2 to 1.3
    + Bump maven-enforcer-plugin from 3.0.0-M3 to 3.0.0
    + Bump jackson-bom from 2.12.3 to 2.12.4
    + Bump stax2-api from 4.2 to 4.2.1
    + Bump actions/setup-java from 1 to 2.2.0
    + Bump actions/setup-java from 1 to 2.2.0
    + Bump maven-gpg-plugin from 1.6 to 3.0.1
    + Bump woodstox-core from 6.2.4 to 6.2.6
    + Bump maven-dependency-plugin from 3.1.2 to 3.2.0
    + Bump maven-javadoc-plugin from 3.2.0 to 3.3.0
    + Bump snakeyaml from 1.28 to 1.29
    + Bump maven-project-info-reports-plugin from 3.1.1 to 3.1.2
    + Bump actions/cache from 2.1.5 to 2.1.6
    + Bump maven-assembly-plugin from 3.2.0 to 3.3.0
    + Bump maven-jxr-plugin from 3.0.0 to 3.1.1
    + Bump xercesImpl from 2.12.0 to 2.12.1
    + [Snyk] Security upgrade org.jsoup:jsoup from 1.13.1 to 1.14.2
    + Bump actions/checkout from 2 to 2.3.4
    + Bump xmlunit-core from 2.8.1 to 2.8.2
    + Bump maven-surefire-report-plugin from 2.22.1 to 2.22.2
    + Bump maven-scm-publish-plugin from 3.0.0 to 3.1.0
    + Bump snakeyaml from 1.26 to 1.28
    + Bump maven-verifier-plugin from 1.0 to 1.1
    + Bump xml-apis from 1.3.04 to 2.0.2
    + Bump jackson-bom from 2.11.3 to 2.12.3
    + Bump xmlunit from 1.2 to 1.6
    + Bump plexus-compiler-javac from 2.1 to 2.8.8
    + Bump actions/cache from v2.1.4 to v2.1.5
    + Bump release-drafter/release-drafter from v5.12.1 to v5.15.0
    + Bump maven-site-plugin from 3.7.1 to 3.9.1
    + Bump maven-jxr-plugin from 2.5 to 3.0.0
    + Bump actions/cache from v2.1.3 to v2.1.4
    + Bump maven-surefire-plugin from 2.22.1 to 2.22.2
    + Bump plexus-compiler-api from 2.1 to 2.8.8
    + Bump maven-resources-plugin from 3.0.1 to 3.2.0
    + Bump release-drafter/release-drafter from v5.11.0 to v5.12.1
    + Bump xmlunit-core from 2.7.0 to 2.8.1
    + Bump actions/cache from v2.1.2 to v2.1.3
    + Bump jaxb-api from 2.1 to 2.3.1
    + Bump junit from 4.12 to 4.13.1
    + Bump actions/cache from v2.1.0 to v2.1.2
    + Bump maven-checkstyle-plugin from 2.15 to 3.1.1
    + Bump xercesImpl from 2.8.1 to 2.12.0 in
    /modello-plugins/modello-plugin-jsonschema
    + Bump xercesImpl from 2.8.1 to 2.12.0 in
    /modello-plugins/modello-plugin-xsd
    + Bump xercesImpl from 2.8.1 to 2.12.0
    + Bump xmlunit-core from 2.3.0 to 2.7.0
    + Bump snakeyaml from 1.12 to 1.26
    + Bump maven-compiler-plugin from 3.8.0 to 3.8.1
    + Bump maven-dependency-plugin from 2.1 to 3.1.2
    + Bump persistence-api from 1.0 to 1.0.2
    + Bump maven-enforcer-plugin from 3.0.0-M1 to 3.0.0-M3
    + Bump maven-pmd-plugin from 3.11.0 to 3.13.0
    + Bump maven-clean-plugin from 3.0.0 to 3.1.0
  * Documentation updates
    + codehaus is dead
    + remove defunct mailing list info
* Tue Mar 22 2022 fstrba@suse.com
- Build with java source and target levels 8
* Mon Apr 26 2021 fstrba@suse.com
- Upgrade to upstream version 1.11
- Depend on the jackson and jsonschema plugins too
* Thu Nov 21 2019 fstrba@suse.com
- Upgrade to upstream version 1.10.0
* Tue Mar 12 2019 fstrba@suse.com
- Initial packaging of modello-maven-plugin separate package
  * Allows building the rest of modello without needing maven
